use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Jérôme
Quelin
Karen
Etheridge
ether
jquelin
Ahmad
Zawawi
azawawi
Olivier
Mengué
dolmen
Kent
Fredric
kentnl
Jesse
Luehrs
doy
David
Golden
dagolden
Randy
Stauner
randy
Harley
Pig
harleypig
Graham
Knop
haarg
fayland
Peter
Shangov
pshangov
Chris
Weyl
cweyl
Ricardo
SIGNES
rjbs
Marcel
Gruenauer
hanekomu
lib
Dist
Zilla
Plugin
Test
Compile
